import React, {Component} from 'react';
import { View, TouchableOpacity, ScrollView , Text ,Image } from 'react-native';
import { connect } from 'react-redux';
import {RTCView} from 'react-native-webrtc';
import { Platform } from '../react';
import Logger from 'react-native-cometchat-calling-component/lib/Logger';
import JitsiManager from 'react-native-cometchat-calling-component/lib/JitsiManager';


class ThumbnailView extends Component{
    constructor(props){
        super(props);
    }

    render(){
        var showImageThumb = JitsiManager.isAudioOnly;

        if(showImageThumb){
            this.props.updateDominantVideoId('localVideo');
        }

        return(
            <ScrollView contentContainerStyle={this.style.lt_container} scrollEnabled={true} showsVerticalScrollIndicator={true} style={ this.style.container }>
                <View style={this.style.lt_container}>
                {
                    this.props.localTracks.map((track,index) => { 
                        if(track.type == "video" && this.props.remoteTracks.length > 0 && this.props.dominantVideoId != 'localVideo'){
                            return (
                                <TouchableOpacity key={index} onPress={()=>{this.props.updateDominantVideoId('localVideo')}}>
                                    {showImageThumb? null : <RTCView
                                        key={index}
                                        objectFit = "cover"
                                        streamURL = { track.getOriginalStream().toURL() }
                                        style={{ height: 100, width: 100, margin: 10}}
                                        zOrder={1}
                                    /> }
                                </TouchableOpacity>
                            )
                        }
                    })
                }
                {
                    this.props.remoteTracks.map((tracks,index) => {
                        if(tracks.ownerId != this.props.dominantVideoId && tracks.video != null){        
                            Logger.log("Tracks id : ",tracks.ownerId);
                            var username,avatar;
                            for(i=0;i<JitsiManager.users.length;i++){
                                if(tracks.ownerId == JitsiManager.users[i].trackid){
                                    username = JitsiManager.users[i].name;
                                    avatar = JitsiManager.users[i].avatar;
                                }
                            }
                            Logger.log("UserName : ",username);
                            return (
                                <TouchableOpacity key={index} onPress={()=>{this.props.updateDominantVideoId(tracks.ownerId)}}>
                                    <View style={{ width: 100,margin: 10}} >

                                        {showImageThumb ? <Image
                                                  style={{ height: 100, width: 100}}
                                                  resizeMode={"cover"}
                                                  source={{uri: avatar}}
                                                /> 
                                          : 
                                          <RTCView
                                            key={index}
                                            objectFit = "cover"
                                            streamURL = {tracks.video.getOriginalStream().toURL()}
                                            zOrder={1}
                                            style={{ height: 100, width: 100}}
                                        />}
                                        

                                        <View style={this.style.container_background}>
                                            <Text numberOfLines={1} ellipsizeMode='tail' style={this.style.name}>
                                                {username}
                                            </Text>
                                        </View>
                                        
                                    </View>
                                    
                                </TouchableOpacity>
                            )
                        }
                    })
                }
                </View>
            </ScrollView>
        )
    }

    style = {
        lt_container : { display:'flex', flexDirection: 'column-reverse', alignItems: 'flex-end', bottom: 0 },
        container: Platform.OS === 'ios' ? { display: 'flex', flex: 1, zIndex: 1, alignSelf: 'flex-end' }  : { flex:1, zIndex:5},
        name: {
            color: "#fff",
            alignSelf:'center',
            justifyContent: 'center',
            zIndex:5,
        },
        container_background:{
            justifyContent: 'center', 
            alignItems: 'center', 
            flexWrap: 'wrap', 
            opacity:0.4,
            backgroundColor: '#2e2f30'
        },
    };
}

function mapStateToProps (state) {
    return {
        localurl: state.url.localUrl,
        localTracks: state.tracks.localTracks,
        remoteTracks: state.tracks.remoteTracks,
        dominantVideoId: state.tracks.dominantVideoId
    }
}

function mapDispatchToProps(dispatch){
    return{
        updateDominantVideoId: (id) => dispatch(data.updateDominantVideoId(id))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(ThumbnailView)